==> cube-ui-1.5.0.tgz: package/src/module.js <==
import Style from './modules/style'

import Button from './modules/button'
import CheckboxGroup from './modules/checkbox-group'
import RadioGroup from './modules/radio'
import Switch from './modules/switch'
import Popup from './modules/popup'
import Dialog from './modules/dialog'
import Toast from './modules/toast'
import Input from './modules/input'
import Validator from './modules/validator'
import Select from './modules/select'
import Textarea from './modules/textarea'
import Rate from './modules/rate'

import Tip from './modules/tip'
import ActionSheet from './modules/action-sheet'
import Slide from './modules/slide'
import IndexList from './modules/index-list'
import TimePicker from './modules/time-picker'
import CascadePicker from './modules/cascade-picker'
import Scroll from './modules/scroll'

import Upload from './modules/upload'
import Swipe from './modules/swipe'

import BScroll from './modules/better-scroll'
import createAPI from './modules/create-api'

const Picker = TimePicker.Picker
const Checkbox = CheckboxGroup.Checkbox
const Loading = Toast.Loading
const SlideItem = Slide.Item
const Radio = RadioGroup.Radio
const SwipeItem = Swipe.Item

export {
  Style,
  Button,
  Scroll,
  Popup,
  Picker,
  TimePicker,
  CascadePicker,
  Select,
  Dialog,
  Tip,
  Toast,
  Input,
  Validator,
  Textarea,
  Rate,
  ActionSheet,
  Checkbox,
  CheckboxGroup,
  Radio,
  RadioGroup,
  Switch,
  Slide,
  SlideItem,
  Loading,
  IndexList,
  Upload,
  Swipe,
  SwipeItem,
  BScroll,
  createAPI
}

==> cube-ui-1.8.2.tgz: package/src/module.js <==
import Style from './modules/style'

import Button from './modules/button'
import CheckboxGroup from './modules/checkbox-group'
import RadioGroup from './modules/radio'
import Switch from './modules/switch'
import Popup from './modules/popup'
import Dialog from './modules/dialog'
import Toast from './modules/toast'
import Input from './modules/input'
import Validator from './modules/validator'
import Select from './modules/select'
import Textarea from './modules/textarea'
import Rate from './modules/rate'
import Form from './modules/form'

import Tip from './modules/tip'
import ActionSheet from './modules/action-sheet'
import Slide from './modules/slide'
import IndexList from './modules/index-list'
import TimePicker from './modules/time-picker'
import SegmentPicker from './modules/segment-picker'
import DatePicker from './modules/date-picker'
import Scroll from './modules/scroll'

import Upload from './modules/upload'
import Swipe from './modules/swipe'
import Drawer from './modules/drawer'

import BScroll from './modules/better-scroll'
import createAPI from './modules/create-api'

const Picker = SegmentPicker.Picker
const CascadePicker = SegmentPicker.CascadePicker
const Checkbox = CheckboxGroup.Checkbox
const FormGroup = Form.Group
const FormItem = Form.Item
const Loading = Toast.Loading
const SlideItem = Slide.Item
const Radio = RadioGroup.Radio
const SwipeItem = Swipe.Item
const DrawerPanel = Drawer.Panel
const DrawerItem = Drawer.Item

export {
  Style,
  Button,
  Scroll,
  Popup,
  Picker,
  TimePicker,
  CascadePicker,
  SegmentPicker,
  DatePicker,
  Select,
  Form,
  FormGroup,
  FormItem,
  Dialog,
  Tip,
  Toast,
  Input,
  Validator,
  Textarea,
  Rate,
  ActionSheet,
  Checkbox,
  CheckboxGroup,
  Radio,
  RadioGroup,
  Switch,
  Slide,
  SlideItem,
  Loading,
  IndexList,
  Upload,
  Swipe,
  SwipeItem,
  Drawer,
  DrawerPanel,
  DrawerItem,
  BScroll,
  createAPI
}
